# Coloriz
 https://pypi.org/project/coloriz
 https://github.com/qmt1/coloriz



# USE

# Gradient

```python
from coloriz import Color

print(Color.gradient(Color.blue_to_red"""
YOUR ASCII ART
"""))

```

# Custom

```python
from coloriz import Color

print(Color.custom("""
YOUR ASCII ART 
""",Color.BLUE,Color.MAGENTA))

```

# Basic

```python
from coloriz import Color

print(Color.RED + 'TEXT')

```


